Welcome to nh3's documentation!
==================================

Installation
------------

.. code-block:: bash

   pip install nh3


Usage
-----

.. code-block:: python

    import nh3

    print(nh3.clean("<b><img src=\"\">I'm not trying to XSS you</b>"))


API Reference
-------------

.. automodule:: nh3
   :members:

.. toctree::
   :maxdepth: 2
   :caption: Contents:



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
